@@ -36,12 +36,12 @@ class DjangoFaker(object):
         field_vals = set(x[0] for x in field.model._default_manager.values_list(field.name))
         self.init_values[field] = field_vals
 
-    def _get_allowed_value(self, source, field):
+    def get_allowed_value(self, source, field):
         retval = source()
         if field is None:
             return retval
 
-        # Enforce unique.  Eensure we don't set the same values, as either
+        # Enforce unique.  Ensure we don't set the same values, as either
         # any of the existing values, or any of the new ones we make up.
         unique = getattr(field, 'unique', None)
         if unique:
@@ -75,7 +75,7 @@ class DjangoFaker(object):
         def source():
             length = random.choice(range(0, max_length + 1))
             return "".join(random.choice(general_chars) for i in xrange(length))
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     def simple_pattern(self, pattern, field=None):
         """
@@ -83,30 +83,30 @@ class DjangoFaker(object):
         ? with a random letter.
         """
         source = lambda: bothify(pattern)
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     def bool(self, field=None):
         """
         Returns a random boolean
         """
         source = lambda: bool(randrange(0, 2))
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     def integer(self, field=None):
         source = lambda: random.randint(-1000000, 1000000)
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     def positive_integer(self, field=None):
         source = lambda: random.randint(0, 1000000)
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     def small_integer(self, field=None):
         source = lambda: random.randint(-32768, +32767)
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     def positive_small_integer(self, field=None):
         source = lambda: random.randint(0, 32767)
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     def datetime(self, field=None, val=None):
         """
@@ -118,7 +118,7 @@ class DjangoFaker(object):
         else:
             source = lambda: datetime.fromtimestamp(int(val.strftime("%s")) +
                                                     randrange(-365*24*3600*2, 365*24*3600*2))
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     def date(self, field=None, val=None):
         """
@@ -128,15 +128,15 @@ class DjangoFaker(object):
         return d.date()
 
     def uk_postcode(self, field=None):
-        return self._get_allowed_value(uk_postcode, field)
+        return self.get_allowed_value(uk_postcode, field)
 
     def uk_county(self, field=None):
         source = lambda: random.choice(data.UK_COUNTIES)
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     def uk_country(self, field=None):
         source = lambda: random.choice(data.UK_COUNTRIES)
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     def lorem(self, field=None, val=None):
         """
@@ -163,7 +163,7 @@ class DjangoFaker(object):
                 return "\n".join(parts)
         else:
             source = self.faker.lorem
-        return self._get_allowed_value(source, field)
+        return self.get_allowed_value(source, field)
 
     ## Other attributes provided by 'Faker':
 
@@ -186,72 +186,86 @@ class DjangoFaker(object):
 
         def func(*args, **kwargs):
             field = kwargs.get('field', None)
-            return self._get_allowed_value(source, field)
+            return self.get_allowed_value(source, field)
         return func
 
 
 class Anonymizer(object):
+    """
+    Base class for all anonymizers. When executed with the ``run()`` method,
+    it will anonymize the data for a specific model.
+    """
 
-   model = None
-   # attributes is a dictionary of {attribute_name: replacer}, where replacer is
-   # a callable that takes as arguments this Anonymizer instance, the object to
-   # be altered, the field to be altered, and the current field value, and
-   # returns a replacement value.
+    model = None
+    # attributes is a dictionary of {attribute_name: replacer}, where replacer is
+    # a callable that takes as arguments this Anonymizer instance, the object to
+    # be altered, the field to be altered, and the current field value, and
+    # returns a replacement value.
 
-   # This signature is designed to be useful for making lambdas that call the
-   # 'faker' instance provided on this class, but it can be used with any
-   # function.
+    # This signature is designed to be useful for making lambdas that call the
+    # 'faker' instance provided on this class, but it can be used with any
+    # function.
 
-   attributes = None
+    attributes = None
 
-   # To impose an order on Anonymizers within a module, this can be set - lower
-   # values are done first.
-   order = 0
+    # To impose an order on Anonymizers within a module, this can be set - lower
+    # values are done first.
+    order = 0
 
-   faker = DjangoFaker()
+    faker = DjangoFaker()
 
-   def get_query_set(self):
-       """
-       Returns the QuerySet to be manipulated
-       """
-       if self.model is None:
-           raise Exception("'model' attribute must be set")
-       return self.model._default_manager.get_query_set().order_by('id')
+    def get_query_set(self):
+        """
+        Returns the QuerySet to be manipulated
+        """
+        if self.model is None:
+            raise Exception("'model' attribute must be set")
+        qs = self.model._default_manager.get_query_set()
+        if len([f for f in self.model._meta.fields if f.name == 'id']) == 1:
+            qs = qs.order_by('id')
+        return qs
 
-   def get_attributes(self):
-       if self.attributes is None:
-           raise Exception("'attributes' attribute must be set")
-       return self.attributes
+    def get_attributes(self):
+        if self.attributes is None:
+            raise Exception("'attributes' attribute must be set")
+        return self.attributes
 
-   def alter_object(self, obj):
-       """
-       Alters all the attributes in an individual object.
+    def alter_object(self, obj):
+        """
+        Alters all the attributes in an individual object.
 
-       If it returns False, the object will not be saved
-       """
-       attributes = self.get_attributes()
-       for attname, replacer in attributes.items():
-           self.alter_object_attribute(obj, attname, replacer)
+        If it returns False, the object will not be saved
+        """
+        attributes = self.get_attributes()
+        if isinstance(attributes, dict):
+            import warnings
+            warnings.warn("The 'attributes' attribute should now be a list of tuples, not a dictionary", PendingDeprecationWarning)
+            items = attributes.items()
+        else:
+            items = attributes
 
-   def alter_object_attribute(self, obj, attname, replacer):
-       """
-       Alters a single attribute in an object.
-       """
-       currentval = getattr(obj, attname)
-       field = obj._meta.get_field_by_name(attname)[0]
-       if isinstance(replacer, str):
-           # 'email' is shortcut for: replacers.email
-           replacer = getattr(replacers, replacer)
-       elif not callable(replacer):
-           raise Exception("Expected callable or string to be passed, got %r." % replacer)
+        for attname, replacer in items:
+            self.alter_object_attribute(obj, attname, replacer)
 
-       replacement = replacer(self, obj, field, currentval)
+    def alter_object_attribute(self, obj, attname, replacer):
+        """
+        Alters a single attribute in an object.
+        """
+        currentval = getattr(obj, attname)
+        field = obj._meta.get_field_by_name(attname)[0]
+        if isinstance(replacer, str):
+            # 'email' is shortcut for: replacers.email
+            replacer = getattr(replacers, replacer)
+        elif not callable(replacer):
+            raise Exception("Expected callable or string to be passed, got %r." % replacer)
 
-       setattr(obj, attname, replacement)
+        replacement = replacer(self, obj, field, currentval)
 
-   def run(self):
-       for obj in self.get_query_set():
-           retval = self.alter_object(obj)
-           if retval is not False:
-            obj.save()
+        setattr(obj, attname, replacement)
+
+    def run(self):
+        for obj in self.get_query_set().iterator():
+            retval = self.alter_object(obj)
+            if retval is not False:
+             obj.save()
 
